@@ -35,13 +35,20 @@ Cometen3::~Cometen3() {
 	quit();
 }
 
-void Cometen3::updateSettings(double time)
+void Cometen3::updateTimeScale(double time)
 {
 	timeScale.setScale(settings->timeScale,
 	                   sceneTimer.getTime(time));
+}
+
+void Cometen3::updateFreeCamSpeed()
+{
 	curveTime = 120.0
 		/ (1.0 + 2*clamp<double>(settings->freeCameraSpeed, 0, 10));
+}
 
+void Cometen3::updateSlowMotionEffects(double time)
+{
 	// Gracefully exits these effects if suddenly turned off in the preview.
 	if (   ( !settings->matrix     && state == S_MATRIX )
 	    || ( !settings->slowMotion && state == S_SLOWMOTION ) )
@@ -50,11 +57,6 @@ void Cometen3::updateSettings(double time)
 	}
 }
 
-void Cometen3::updateBackground(const GLuint* text )
-{
-	scene->textures = text;
-}
-
 void Cometen3::init(const GLuint* text,
                     int resX, int resY, double time) 
 {
