@@ -94,9 +94,10 @@ public:
 	void process(double time);
 	void render();
 	void resize(int resX, int resY);
-	void updateSettings(double time);
+	void updateTimeScale(double time);
+	void updateFreeCamSpeed();
+	void updateSlowMotionEffects(double time);
 	void updateSizeScale();
-	void updateBackground(const GLuint* textures );
 
 private:
 	void changeViewport(int x, int y, int width, int height);
