@@ -137,7 +137,8 @@ void CometenScene::createComet(double time) {
 	
 	getCometColors(acolor, ecolor);
 	
-	Vec3f start = Vec3f::randomUnit() * getBoxHeight()/20;
+	double d = boxWidth < boxHeight ? boxWidth : boxHeight;
+	Vec3f start = Vec3f::randomUnit() * d/3;
 	
 	if (frand() >= 0.5) {
 		newc = new 
