@@ -70,6 +70,15 @@ texture(_texture)
 			setupTextureCoordArray();
 	}
 
+    /* Intel cards seem to have memory problems with non-integer point sizes.
+     * Since point antialiasing is disabled anyway, we can convert to int
+     * without affecting the appearance.
+     */
+	double pointRange[2];
+	glGetDoublev(GL_SMOOTH_POINT_SIZE_RANGE, pointRange);
+	particleSize += 0.5;
+	particleSize = clamp<int>(particleSize, pointRange[0], pointRange[1]);
+
 	particleArr = new Particle[maxParticle];
 	indexArr = new int[maxParticle];
 	
@@ -231,6 +240,7 @@ void ParticleSystem::renderPoint() {
 	glDisable(GL_POINT_SPRITE_ARB);
 	glTexEnvf(GL_POINT_SPRITE_ARB, GL_COORD_REPLACE_ARB, GL_FALSE);
 	
+	glDisable(GL_TEXTURE_2D);
 	glDisable(GL_BLEND);
 }
 
